Exception: Micdrop::SourceError
- Inherits:
-
StandardError
- Object
- StandardError
- Micdrop::SourceError
- Defined in:
- lib/micdrop/errors.rb
Overview
An error on the source side of the migration
An error on the source side of the migration