Exception: Micdrop::ValueError
- Inherits:
-
StandardError
- Object
- StandardError
- Micdrop::ValueError
- Defined in:
- lib/micdrop/errors.rb
Overview
An error with the current data value that prevents conversion operations from working
An error with the current data value that prevents conversion operations from working